// src/components/GroupCheckbox/index.tsx
import { useEffect, useState } from "react";
import { jsx, jsxs } from "react/jsx-runtime";
function GroupCheckbox(props) {
  const {
    list = [],
    hasSearch = false,
    setSelectedItems,
    parentClassName = "",
    checkboxClassName = "",
    checkboxFilledClassName = "",
    labelClassName = "",
    searchOption = { label: "", className: "", disabled: false },
    selectType = "single",
    customIcon = null
  } = props;
  const [mainData, setMainData] = useState(list);
  const [showData, setShowData] = useState([]);
  const [search, setSearch] = useState("");
  useEffect(() => {
    setShowData(mainData);
    let selectedFilter = mainData.filter((item) => item.checked);
    if (selectType == "single") {
      setSelectedItems(selectedFilter[0]);
    } else if (selectType == "multiple") {
      setSelectedItems(selectedFilter);
    }
  }, [mainData]);
  useEffect(() => {
    let newList = mainData.filter((item) => item.name.includes(search));
    if (!newList) return;
    setShowData(newList);
  }, [search, mainData]);
  function checkBoxHandler(e) {
    let updateList;
    if (selectType == "multiple") {
      updateList = mainData.map((item) => {
        if (item.name == e.target.id) {
          if (item.checked) {
            item.checked = false;
          } else {
            item.checked = true;
          }
        }
        return item;
      });
    } else if (selectType == "single") {
      updateList = mainData.map((item) => {
        if (item.name == e.target.id) {
          if (item.checked) {
            item.checked = false;
          } else {
            item.checked = true;
          }
        } else {
          if (item.checked) {
            item.checked = false;
          }
        }
        return item;
      });
    }
    if (!updateList) return;
    setMainData(updateList);
  }
  return /* @__PURE__ */ jsxs("div", { className: parentClassName, children: [
    hasSearch && /* @__PURE__ */ jsx(
      "input",
      {
        type: "text",
        placeholder: searchOption.label,
        disabled: searchOption.disabled,
        className: searchOption.className,
        onChange: (e) => setSearch(e.target.value)
      }
    ),
    showData.length ? showData.map((item, index) => {
      return /* @__PURE__ */ jsx(
        Checkbox,
        {
          disabled: item.disabled,
          parentClassName: checkboxFilledClassName,
          labelClassName,
          inputClassName: checkboxClassName,
          name: item.name || "",
          checked: item.checked,
          label: item.label || item.name,
          onChange: checkBoxHandler,
          customIcon
        },
        index
      );
    }) : hasSearch ? searchOption.emptyComponent || /* @__PURE__ */ jsx("p", { children: "Not Found!" }) : null
  ] });
}

// src/components/Checkbox/index.tsx
import { jsx as jsx2, jsxs as jsxs2 } from "react/jsx-runtime";
function Checkbox({
  name,
  onChange,
  id,
  label,
  checked = false,
  disabled = false,
  parentClassName,
  labelClassName,
  inputClassName,
  customIcon = null
}) {
  const customCheckboxStyle = {
    backgroundImage: `url(${checked ? customIcon?.checked : customIcon?.unChecked})`,
    backgroundSize: "cover",
    width: customIcon?.size || 16,
    height: customIcon?.size || 16
  };
  const inputContainerStyle = {
    width: customIcon?.size || 16,
    height: customIcon?.size || 16
  };
  return /* @__PURE__ */ jsxs2("label", { className: parentClassName, children: [
    customIcon ? /* @__PURE__ */ jsxs2("div", { style: inputContainerStyle, className: "cursor-pointer", children: [
      /* @__PURE__ */ jsx2(
        "input",
        {
          className: ` absolute z-10 visible opacity-0`,
          type: "checkbox",
          id: name,
          "data-id": id || name,
          name,
          checked,
          onChange,
          disabled
        }
      ),
      /* @__PURE__ */ jsx2(
        "label",
        {
          htmlFor: name,
          style: customCheckboxStyle,
          className: "block bg-cover cursor-pointer"
        }
      )
    ] }) : /* @__PURE__ */ jsx2(
      "input",
      {
        className: inputClassName,
        type: "checkbox",
        id: name,
        "data-id": id || name,
        name,
        checked,
        onChange,
        disabled
      }
    ),
    label ? /* @__PURE__ */ jsx2("label", { className: labelClassName, htmlFor: name, children: label }) : null
  ] });
}
export {
  GroupCheckbox,
  Checkbox as default
};
